@@ -1,21 +1,23 @@
+{-# LANGUAGE DefaultSignatures, DeriveAnyClass, DeriveGeneric #-}
 {-DHUN| general Fonts configuration modules DHUN-}
 module BaseFont where
 import Data.Char
 import Data.Array
 import Data.Tuple
-
+import Data.Serialize
+import GHC.Generics
 {-DHUN| Basic Fontstyle, may be either normal of monospaced or small caps DHUN-}
 
 data FontStyleBase = Normal
                    | Mono
                    | Smallcaps
-                   deriving (Eq, Ord, Show)
+                   deriving (Eq, Ord, Show, Read, Serialize, Generic)
 
 {-DHUN| Full discription of style of a font. Consists of Basic Fontstyle plus boolean for bold and/or italic DHUN-}
 
 data FontStyle = FontStyle{stylebase :: FontStyleBase,
                            bold :: Bool, italic :: Bool}
-               deriving (Eq, Ord, Show)
+               deriving (Eq, Ord, Show, Read, Serialize, Generic)
 
 {-DHUN| Font, a list of ttf font file currently used by mediawiki2latex DHUN-}
 
@@ -37,7 +39,7 @@ data Font = GnuUnifont
           | ComputerModernRomanBold
           | ComputerModernRomanItalic
           | ComputerModernRomanBoldItalic
-          deriving (Eq, Ord, Show, Ix)
+          deriving (Eq, Ord, Show, Ix, Read, Serialize, Generic)
 
 {-DHUN| list of Fonts. The first element in the list is the fonts that is preferred to be used. If it can not be used for some reason the next font in the list is used. Note that the list is denoted in reverse order and put into the right order by the reverse function in the way it is just written at this point of the source file DHUN-}
 
