@@ -127,7 +127,7 @@ wikiImageToHtml l
                          " src=\"./images/" ++
                            (n st) ++
                              "." ++
-                               ext ++
+                               (if (ext=="svg" && (not (MyState.vector st))) then "png" else ext) ++
                                  "\" style=\"width: " ++
                                    (if (tb st) then "100.0" else (mysize st)) ++
                                      "%;\">" ++
@@ -291,6 +291,8 @@ treeToHtml2 ll
                       else return [c]
                put st{lastChar = c}
                return x
+        nodeToHtml (Environment HtmlChar (Str s) _)
+          = return ("&"++s++";")
         nodeToHtml (Environment Wikilink _ l)
           = do st <- get
                if getInHeading st then return $ wikiLinkCaption l st else
