@@ -537,7 +537,7 @@ goodtags1
      "applet", "script", "button", "select", "section", "legend",
      "strike", "object", "input", "center", "legend", "iframe", "small",
      "video", "audio", "style", "input", "label", "tbody", "thead",
-     "title", "frame", "param", "base", "area", "font", "code", "span",
+     "title", "track" ,"frame", "param", "base", "area", "font", "code", "span",
      "abbr", "body", "link", "menu", "math", "meta", "samp", "cite",
      "head", "html", "poem", "form", "cite", "ref", "div", "pre", "sub",
      "sup", "big", "del", "map", "bdo", "var", "dfn", "kbd", "col",
