@@ -18,8 +18,8 @@ import Control.Monad
 import Licenses
 import Tools
 import ImperativeState
-import HtmlParser (parseHtml)
-
+import HtmlParser (parseHtmlFast)
+import Control.DeepSeq
 makeUrl2 :: String -> String -> [Char]
 makeUrl2 theLemma theHost
   = (unify . exportURL)
@@ -91,7 +91,7 @@ simpleContributors theLemma theHost uu st
                    Just u -> exportURL u
                    _ -> makeUrl3 theLemma theHost
        yy <- geturl theUrl3
-       let gg = (deepGet "li" "id" "ca-history" (parseHtml yy))
+       let gg = (deepGet "li" "id" "ca-history" (parseHtmlFast yy))
        let theUrl
              = makeUrl4
                  (case gg of
@@ -117,14 +117,16 @@ simpleContributors theLemma theHost uu st
        xx <- geturl theUrl
        let y = decodeString yy
        let x = decodeString xx
+       let ff= (force (parseHtmlFast x))
        let dd
-             = ((deepGet "a" "class" "new mw-userlink" (parseHtml x))
-                  ++ (deepGet "a" "class" "mw-userlink" (parseHtml x)))
+             = (((deepGet "a" "class" "new mw-userlink" ff)
+                  ++ (deepGet "a" "class" "mw-userlink" ff)))
                  :: [Anything Char]
+
        let ll = (filter pre (map go dd))
        let n = (nub ll) :: [(String, String)]
        let out = map go2 (zip (map (count ll) n) n)
-       let ht = (parseHtml y)
+       let ht = (parseHtmlFast y)
        case (getAuthor ht) of
            Just zz -> return
                         [(fst
