@@ -1,4 +1,4 @@
-{-# LANGUAGE StandaloneDeriving #-}
+{-# LANGUAGE DefaultSignatures, DeriveAnyClass, DeriveGeneric, StandaloneDeriving #-}
 {-DHUN| module for processing urls and downloading their content with repect to mediawiki DHUN-}
 module UrlAnalyse
        (getpage, analyse, analyseFull, unify, WikiUrl, getLemma,
@@ -23,11 +23,24 @@ import qualified Data.ByteString as BStr
 import qualified Data.ByteString.UTF8 as UTF8Str
 import qualified Network.HTTP.Types as T
 import qualified Network.HTTP.Types.Version as V
+import Data.Serialize
+import GHC.Generics
 
 deriving instance Read URL.URL
 deriving instance Read URL.Host
 deriving instance Read URL.Protocol
 deriving instance Read URL.URLType
+deriving instance Serialize URL
+deriving instance Generic URL
+deriving instance Serialize URLType
+deriving instance Generic URLType
+deriving instance Serialize Host
+deriving instance Generic Host
+deriving instance Serialize Protocol
+deriving instance Generic Protocol
+
+
+
 
 {-DHUN| This represents the main url of a wiki page. So the url of the wiki page that should be converted to latex. It is a tuple wrapped into the maybe monad, to deal with case in which the url could not be parsed. The first element of the tuple is just the main url parsed with Network.URL The second element is a list of urls. These URLs are possible base urls for wiki pages. So en.wikipedia.org/wiki/Foobar has got the main url en.wikipedia.org/wiki/Foobar and one of the base urls us en.wikipedia.org/wiki/. Base urls are important since the wiki source related to the main url might include subpage in wiki notation that is [[JohnDow]]. The actual url to look up JohnDow is the baseurl plus JohnDow so that is en.wikipedia.org/wiki/JohnDow Since also images in the commons and similar things are possible, the are usually some baseurls to be looked at. This way the base URLs have to be a list. DHUN-}
  
@@ -43,7 +56,7 @@ wikiUrl fu = return (url fu, alternatives fu)
 
 data FullWikiUrl = FullWikiUrl{url :: URL, alternatives :: [URL],
                                hostname :: String, lemma :: String}
-                 deriving (Eq, Ord)
+                 deriving (Eq, Ord, Serialize, Generic)
  
 
 {-DHUN| base instance of type FullWikiUrl, to be filled with useful data using the record syntax DHUN-}
