@@ -120,6 +120,10 @@ normalizeExtensionHtml ('g' : ('i' : ('f' : _))) = "gif"
 normalizeExtensionHtml ('p' : ('n' : ('g' : _))) = "png"
 normalizeExtensionHtml ('t' : ('i' : ('f' : ('f' : _)))) = "png"
 normalizeExtensionHtml ('t' : ('i' : ('f' : _))) = "png"
+normalizeExtensionHtml  ('s' : ('t' : ('l' : _))) = "png"
+normalizeExtensionHtml  ('x' : ('c' : ('f' : _))) = "png"
+normalizeExtensionHtml  ('d' : ('j' : ('v' :('u': _)))) = "png"
+normalizeExtensionHtml  ('w' : ('e' : ('b' :('p': _)))) = "png"
 normalizeExtensionHtml (' ' : xs) = normalizeExtension xs
 normalizeExtensionHtml (x : xs) = x : (normalizeExtension xs)
 normalizeExtensionHtml [] = []
@@ -135,7 +139,9 @@ normalizeExtension ('p' : ('n' : ('g' : _))) = "png"
 normalizeExtension ('t' : ('i' : ('f' : ('f' : _)))) = "png"
 normalizeExtension ('t' : ('i' : ('f' : _))) = "png"
 normalizeExtension ('s' : ('t' : ('l' : _))) = "png"
+normalizeExtension ('x' : ('c' : ('f' : _))) = "png"
 normalizeExtension ('d' : ('j' : ('v' :('u': _)))) = "png"
+normalizeExtension  ('w' : ('e' : ('b' :('p': _)))) = "png"
 normalizeExtension (' ' : xs) = normalizeExtension xs
 normalizeExtension (x : xs) = x : (normalizeExtension xs)
 normalizeExtension [] = []
@@ -150,7 +156,10 @@ normalizeExtension2 ('g' : ('i' : ('f' : _))) = "gif"
 normalizeExtension2 ('p' : ('n' : ('g' : _))) = "png"
 normalizeExtension2 ('t' : ('i' : ('f' : ('f' : _)))) = "tif"
 normalizeExtension2 ('t' : ('i' : ('f' : _))) = "tif"
+normalizeExtension2 ('s' : ('t' : ('l' : _))) = "stl"
+normalizeExtension2 ('x' : ('c' : ('f' : _))) = "xcf"
 normalizeExtension2 ('d' : ('j' : ('v' :('u': _)))) = "djvu"
+normalizeExtension2  ('w' : ('e' : ('b' :('p': _)))) = "webp"
 normalizeExtension2 (' ' : xs) = normalizeExtension xs
 normalizeExtension2 (x : xs) = x : (normalizeExtension xs)
 normalizeExtension2 [] = []
